@@ -208,21 +208,17 @@
 #define ICS_NAMES "\
 chessclub.com /icsport=5000 /icshelper=timestamp\n\
 freechess.org /icsport=5000 /icshelper=timeseal\n\
-server.uschesslive.org /icsport=5000 /icshelper=timeseal\n\
-europe.freechess.org /icsport=5000 /icshelper=timeseal\n\
-primrose.warwick.ac.uk /icsport=5000 /icshelper=timeseal\n\
-fly.cc.fer.hr /icsport=7890\n\
-dics.dds.nl /icsport=5000 /icshelper=timeseal\n\
-chess.unix-ag.uni-kl.de /icsport=5000 /icshelper=timeseal\n\
-chess.mds.mdh.se /icsport=5555 /icshelper=timeseal\n\
-chess.mds.mdh.se /icsport=5000\n\
-vics.ver.ucc.mx /icsport=5000\n\
-zics.org /icsport=5000\n\
-chess-server.spidernet.com.cy /icsport=5000 /icshelper=timeseal\n\
-ajedrez.cec.uchile.cl /icsport=5000\n\
-jogo.cex.org.br /icsport=5000\n\
-queen.chessclub.com /icsport=5000 /icshelper=timestamp\n\
+global.chessparlor.com /icsport=6000 /icshelper=timeseal\n\
 chess.net /icsport=5000\n\
+chess-square.com /icsport=5000\n\
+zics.org /icsport=5000\n\
+jogo.cex.org.br /icsport=5000\n\
+ajedrez.cec.uchile.cl /icsport=5000\n\
+fly.cc.fer.hr /icsport=7890\n\
+freechess.nl /icsport=5000 /icshelper=timeseal\n\
+jeu.echecs.com /icsport=5000\n\
+chess.unix-ag.uni-kl.de /icsport=5000 /icshelper=timeseal\n\
+chess.mds.mdh.se /icsport=5000\n\
 "
 
 #define ICS_TEXT_MENU_DEFAULT "\
