@@ -37,7 +37,7 @@
 
 #if __GNUC__
 #include <errno.h>
-#include <strings.h>
+#include <string.h>
 #endif
 
 /* Imports from winboard.c */
@@ -135,11 +135,13 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 {
   static Boolean oldShowCoords;
   static Boolean oldBlindfold;
+  static Boolean oldShowButtonBar;
 
   switch (message) {
   case WM_INITDIALOG: /* message: initialize dialog box */
     oldShowCoords = appData.showCoords;
     oldBlindfold  = appData.blindfold;
+    oldShowButtonBar = appData.showButtonBar;
 
     /* Center the dialog over the application window */
     CenterWindow (hDlg, GetWindow (hDlg, GW_OWNER));
@@ -161,6 +163,7 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
     CHECK_BOX(OPT_PonderNextMove, appData.ponderNextMove);
     CHECK_BOX(OPT_PopupExitMessage, appData.popupExitMessage);
     CHECK_BOX(OPT_PopupMoveErrors, appData.popupMoveErrors);
+    CHECK_BOX(OPT_ShowButtonBar, appData.showButtonBar);
     CHECK_BOX(OPT_ShowCoordinates, appData.showCoords);
     CHECK_BOX(OPT_ShowThinking, appData.showThinking);
     CHECK_BOX(OPT_TestLegality, appData.testLegality);
@@ -201,6 +204,7 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
       appData.ponderNextMove       = IS_CHECKED(OPT_PonderNextMove);
       appData.popupExitMessage     = IS_CHECKED(OPT_PopupExitMessage);
       appData.popupMoveErrors      = IS_CHECKED(OPT_PopupMoveErrors);
+      appData.showButtonBar        = IS_CHECKED(OPT_ShowButtonBar);
       appData.showCoords           = IS_CHECKED(OPT_ShowCoordinates);
       appData.showThinking         = IS_CHECKED(OPT_ShowThinking);
       appData.testLegality         = IS_CHECKED(OPT_TestLegality);
@@ -228,8 +232,10 @@ GeneralOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
        */
       EndDialog(hDlg, TRUE);
 
-      if ((oldShowCoords != appData.showCoords) || 
-	  (oldBlindfold != appData.blindfold)) {
+      if (oldShowButtonBar != appData.showButtonBar) {
+	InitDrawingSizes(boardSize, 0);
+      } else if ((oldShowCoords != appData.showCoords) || 
+		 (oldBlindfold != appData.blindfold)) {
 	InvalidateRect(hwndMain, &boardRect, FALSE);
       }
 
@@ -1467,11 +1473,11 @@ InitSoundComboData(SoundComboData *scd)
   /* copy current sound settings to combo array */
 
   for ( sc = (SoundClass)0; sc < NSoundClasses; sc++) {
-    scd[sc].name = _strdup(sounds[sc].name);
+    scd[sc].name = strdup(sounds[sc].name);
   }
   for ( cc = (ColorClass)0; cc < NColorClasses - 2; cc++) {
     index = (int)cc + (int)NSoundClasses;
-    scd[index].name = _strdup(textAttribs[cc].sound.name);
+    scd[index].name = strdup(textAttribs[cc].sound.name);
   }
 }
 
@@ -1650,7 +1656,7 @@ SoundOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
        * newly selected event and update the dialog. 
        */
       radio = SoundDialogWhichRadio(hDlg);
-      newName = _strdup(SoundDialogGetName(hDlg, radio));
+      newName = strdup(SoundDialogGetName(hDlg, radio));
       
       if (strcmp(newName, soundComboData[index].name) != 0) {
 	free(soundComboData[index].name);
@@ -1671,7 +1677,7 @@ SoundOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
        * save the name for the currently selected sound event 
        */
       radio = SoundDialogWhichRadio(hDlg);
-      newName = _strdup(SoundDialogGetName(hDlg, radio));
+      newName = strdup(SoundDialogGetName(hDlg, radio));
 
       if (strcmp(soundComboData[index].name, newName) != 0) {
 	free(soundComboData[index].name);
@@ -1686,7 +1692,7 @@ SoundOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
       for ( sc = (SoundClass)0; sc < NSoundClasses; sc++) {
 	if (strcmp(soundComboData[sc].name, sounds[sc].name) != 0) {
 	  free(sounds[sc].name);
-	  sounds[sc].name = _strdup(soundComboData[sc].name);
+	  sounds[sc].name = strdup(soundComboData[sc].name);
 	  MyLoadSound(&sounds[sc]);
 	}
       }
@@ -1695,7 +1701,7 @@ SoundOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 	if (strcmp(soundComboData[index].name, 
 		   textAttribs[cc].sound.name) != 0) {
 	  free(textAttribs[cc].sound.name);
-	  textAttribs[cc].sound.name = _strdup(soundComboData[index].name);
+	  textAttribs[cc].sound.name = strdup(soundComboData[index].name);
 	  MyLoadSound(&textAttribs[cc].sound);
 	}
       }
@@ -1716,17 +1722,17 @@ SoundOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
       scd = &soundComboData[0];
       while (scd->label != NULL) {
 	if (scd->name != NULL) free(scd->name);
-	scd->name = _strdup("");
+	scd->name = strdup("");
 	scd++;
       }
       free(soundComboData[(int)SoundBell].name);
-      soundComboData[(int)SoundBell].name = _strdup(SOUND_BELL);
+      soundComboData[(int)SoundBell].name = strdup(SOUND_BELL);
       DisplaySelectedSound(hDlg, hBISN, soundComboData[index].name);
       break;
 
     case OPT_PlaySound:
       radio = SoundDialogWhichRadio(hDlg);
-      tmp.name = _strdup(SoundDialogGetName(hDlg, radio));
+      tmp.name = strdup(SoundDialogGetName(hDlg, radio));
       tmp.data = NULL;
       MyLoadSound(&tmp);
       MyPlaySound(&tmp);
@@ -2007,7 +2013,7 @@ CommPortOptionsDialog(HWND hDlg, UINT message, WPARAM wParam,	LPARAM lParam)
 	return TRUE;
       }
       SendMessage(hwndCombo, WM_GETTEXT, (WPARAM) MSG_SIZ, (LPARAM) buf);
-      appData.icsCommPort = _strdup(buf);
+      appData.icsCommPort = strdup(buf);
       if (hCommPort != NULL) {
 	CloseHandle(hCommPort);
 	hCommPort = NULL;
@@ -2250,16 +2256,16 @@ SaveOptionsDialog(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 	  }
 	  if ((isalpha(buf[0]) && buf[1] == ':') ||
 	    (buf[0] == '\\' && buf[1] == '\\')) {
-	    appData.saveGameFile = _strdup(buf);
+	    appData.saveGameFile = strdup(buf);
 	  } else {
 	    char buf2[MSG_SIZ], buf3[MSG_SIZ];
 	    char *dummy;
 	    GetCurrentDirectory(MSG_SIZ, buf3);
 	    SetCurrentDirectory(installDir);
 	    if (GetFullPathName(buf, MSG_SIZ, buf2, &dummy)) {
-	      appData.saveGameFile = _strdup(buf2);
+	      appData.saveGameFile = strdup(buf2);
 	    } else {
-	      appData.saveGameFile = _strdup(buf);
+	      appData.saveGameFile = strdup(buf);
 	    }
 	    SetCurrentDirectory(buf3);
 	  }
@@ -2394,10 +2400,10 @@ TimeControl(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
 	  return FALSE;
 	}
       }
-      appData.timeControl = _strdup(buf);
+      appData.timeControl = strdup(buf);
       appData.movesPerSession = mps;
       appData.timeIncrement = increment;
-      Reset(TRUE);
+      Reset(TRUE, TRUE);
       EndDialog(hDlg, TRUE);
       return TRUE;
 
