@@ -1,9 +1,9 @@
 /*
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
- * $Id: zippy.c,v 1.59 2000/12/17 01:55:48 mann Exp $
+ * $Id: zippy.c,v 1.62 2001/12/09 23:02:59 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
- * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
+ * Enhancements Copyright 1992-2001 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
@@ -333,8 +333,9 @@ void Speak(how, whom)
     }
     done = FALSE;
 
-    strcpy(zipbuf, ics_prefix);
-    strcat(zipbuf, how);
+    /* Don't use ics_prefix; we need to let FICS expand the alias i -> it,
+       but use the real command "i" on ICC */
+    strcpy(zipbuf, how);
     strcat(zipbuf, " ");
     if (whom != NULL) {
 	strcat(zipbuf, whom);
@@ -429,7 +430,7 @@ int ZippyControl(buf, i)
 	    SendToICS(reply);
 	    if (strcmp(zippyPartner, player) != 0) {
 		strcpy(zippyPartner, player);
-		SendToProgram(reply, &first);
+		SendToProgram(reply + strlen(ics_prefix), &first);
 	    }
 	} else if (appData.zippyBughouse > 0) {
 	    sprintf(reply, "%sdecline %s\n", ics_prefix, player);
@@ -733,8 +734,14 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
        based on rated, variant, base, and increment, but it is
        easier to use the ICS formula feature instead. */
 
-    if ((variant == VariantLoadable) || 
-	(StrStr(appData.zippyVariants, varname) == NULL)) {
+    if (variant == VariantLoadable) {
+        sprintf(buf,
+	 "%stell %s This computer can't play wild type %s\n%sdecline %s\n",
+		ics_prefix, opponent, swild, ics_prefix, opponent);
+	SendToICS(buf);
+	return;
+    }
+    if (StrStr(appData.zippyVariants, varname) == NULL) {
         sprintf(buf,
 	 "%stell %s This computer can't play %s [%s], only %s\n%sdecline %s\n",
 		ics_prefix, opponent, swild, varname, appData.zippyVariants,
@@ -765,8 +772,8 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
 
     /* Engine still thinking about last game? */
     if (first.lastPing != first.lastPong) {
-      sprintf(buf, "%stell %s Oops, I'm not quite ready for a new game yet.\n",
-	      ics_prefix, opponent);
+      sprintf(buf, "%stell %s I'm not quite ready for a new game yet; try again soon.\n%sdecline %s\n",
+	      ics_prefix, opponent, ics_prefix, opponent);
       SendToICS(buf);
       return;
     }
@@ -898,6 +905,7 @@ void ZippyFirstBoard(moveNum, basetime, increment)
     char buf[MSG_SIZ];
     int w, b;
     char *opp = (gameMode==IcsPlayingWhite ? gameInfo.black : gameInfo.white);
+    Boolean sentPos = FALSE;
 
     /* Initialize chess program with data from the first board 
        of a new or resumed game */
@@ -908,8 +916,11 @@ void ZippyFirstBoard(moveNum, basetime, increment)
       SendToProgram(buf, &first);
     }
 
-    if (startedFromSetupPosition || (!appData.getMoveList && moveNum > 0)) {
-	SendBoard(&first, moveNum);
+    if ((startedFromSetupPosition && moveNum == 0) ||
+	(!appData.getMoveList && moveNum > 0)) {
+      SendToProgram("force\n", &first);
+      SendBoard(&first, moveNum);
+      sentPos = TRUE;
     }
 
     sprintf(buf, "level 0 %d %d\n", basetime, increment);
@@ -946,37 +957,46 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 	strcpy(ics_handle, gameInfo.white);
 	sprintf(buf, "rating %d %d\n", w, b);
 	SendToProgram(buf, &first);
-	if (appData.getMoveList) {
-	    /* Resume from adjournments with move list, to be sent later */
-	    if (moveNum == 0) {
-		/* Not an adjournment */
+	if (sentPos) {
+	    /* Position sent above, engine is in force mode */
+	    if (WhiteOnMove(moveNum)) {
+	      /* Engine is on move now */
+	      if (first.sendTime) {
 		if (first.useColors) {
 		  SendToProgram("black\n", &first); /*gnu kludge*/
 		  SendTimeRemaining(&first, TRUE);
-		  SendToProgram("white\ngo\n", &first);
+		  SendToProgram("white\n", &first);
 		} else {
 		  SendTimeRemaining(&first, TRUE);
-		  SendToProgram("go\n", &first);
+		}
+	      }
+	      SendToProgram("go\n", &first);
+	    } else {
+	        /* Engine's opponent is on move now */
+	        if (first.usePlayother) {
+		  if (first.sendTime) {
+		    SendTimeRemaining(&first, TRUE);
+		  }
+		  SendToProgram("playother\n", &first);
+		} else {
+		  /* Need to send a "go" after opponent moves */
+		  firstMove = TRUE;
 		}
 	    }
 	} else {
-	    /* Resume from adjournments with position only, sent above */
-	    if (WhiteOnMove(moveNum)) {
+	    /* Position not sent above, move list might be sent later */
+	    if (moveNum == 0) {
+	        /* No move list coming; at start of game */
+	      if (first.sendTime) {
 		if (first.useColors) {
 		  SendToProgram("black\n", &first); /*gnu kludge*/
 		  SendTimeRemaining(&first, TRUE);
-		  SendToProgram("white\ngo\n", &first);
+		  SendToProgram("white\n", &first);
 		} else {
 		  SendTimeRemaining(&first, TRUE);
-		  SendToProgram("go\n", &first);
-		}
-	    } else {
-	        if (first.usePlayother) {
-		  SendToProgram("playother\n", &first);
-		  firstMove = FALSE;
-		} else {
-		  firstMove = TRUE;
 		}
+	      }
+	      SendToProgram("go\n", &first);
 	    }
 	}
     } else if (gameMode == IcsPlayingBlack) {
@@ -987,28 +1007,36 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 	strcpy(ics_handle, gameInfo.black);
 	sprintf(buf, "rating %d %d\n", b, w);
 	SendToProgram(buf, &first);
-	if (appData.getMoveList) {
-	    /* Resume from adjournments with move list, to be sent later */
-	    /* Nothing to do here */
-	} else {
-	    /* Resume from adjournments with position only, sent above */
+	if (sentPos) {
+	    /* Position sent above, engine is in force mode */
 	    if (!WhiteOnMove(moveNum)) {
+	        /* Engine is on move now */
+	      if (first.sendTime) {
 		if (first.useColors) {
 		  SendToProgram("white\n", &first); /*gnu kludge*/
 		  SendTimeRemaining(&first, FALSE);
-		  SendToProgram("black\ngo\n", &first);
+		  SendToProgram("black\n", &first);
 		} else {
 		  SendTimeRemaining(&first, FALSE);
-		  SendToProgram("go\n", &first);
 		}
+	      }
+	      SendToProgram("go\n", &first);
 	    } else {
+	        /* Engine's opponent is on move now */
 	        if (first.usePlayother) {
+		  if (first.sendTime) {
+		    SendTimeRemaining(&first, FALSE);
+		  }
 		  SendToProgram("playother\n", &first);
 		} else {
-		  /* nothing to do here */
+		  /* Need to send a "go" after opponent moves */
+		  firstMove = TRUE;
 		}
 	    }
-	}
+	} else {
+	    /* Position not sent above, move list might be sent later */
+	    /* Nothing needs to be done here */
+	}	
     }
 }
 
